@@ -23,53 +23,51 @@ class ArjunaOption(Enum):
     ARJUNA_ROOT_DIR = auto()
     ARJUNA_EXTERNAL_TOOLS_DIR = auto()
     ARJUNA_EXTERNAL_IMPORTS_DIR = auto()
-    PYTHON_LOG_NAME = auto()
     LOG_NAME = auto()
 
     RUN_ID = auto()
+    RUN_ENV_NAME = auto()
+    RUN_ENV_CONF_DIR = auto()
+    RUN_HOST_OS = auto()
 
     LOG_FILE_LEVEL = auto()
     LOG_CONSOLE_LEVEL = auto()
 
-    LOCALE = auto()
+    L10N_LOCALE = auto()
+    L10N_STRICT = auto()
+    L10N_DIR = auto()
+    L10N_EXCEL_DIR = auto()
+    L10N_JSON_DIR = auto()
 
     PROJECT_NAME = auto()
     PROJECT_ROOT_DIR = auto()
     PROJECT_CONF_FILE = auto()
-    PROJECT_TESTS_DIR = auto()
-    PROJECT_REPORT_DIR = auto()
-    PROJECT_REPORT_FORMATS = auto()
-    PROJECT_RUN_REPORT_DIR = auto()
-    PROJECT_RUN_REPORT_XML_DIR = auto()
-    PROJECT_RUN_REPORT_HTML_DIR = auto()
-    PROJECT_RUN_LOG_DIR = auto()
-    PROJECT_RUN_SCREENSHOTS_DIR = auto()
+
+    TESTS_DIR = auto()
+    REPORTS_DIR = auto()
+    REPORT_FORMATS = auto()
+    REPORT_DIR = auto()
+    REPORT_XML_DIR = auto()
+    REPORT_HTML_DIR = auto()
+    LOG_DIR = auto()
+    SCREENSHOTS_DIR = auto()
+    CONF_DIR = auto()
 
     DATA_DIR = auto()
-    DATA_SOURCES_DIR = auto()
-    DATA_REFERENCES_DIR = auto()
-    DATA_REFERENCES_COLUMN_DIR = auto()
-    DATA_REFERENCES_ROW_DIR = auto()
-    DATA_L10_DIR = auto()
-    DATA_L10_EXCEL_DIR = auto()
-    SCREENSHOTS_DIR = auto()
-    CONFIG_DIR = auto()
+    DATA_SRC_DIR = auto()
+    DATA_REF_DIR = auto()
+    DATA_REF_COLUMN_DIR = auto()
+    DATA_REF_ROW_DIR = auto()
 
     SETU_PROJECT_DIRS_FILES = auto()
-    REPORT_DIR = auto()
-    ARCHIVES_DIR = auto()
 
-    AUT_BASE_URL = auto()
-
-    TESTRUN_ENVIRONMENT = auto()
-    TESTRUN_HOST_OS = auto()
+    APP_URL = auto()
 
     SETU_GUIAUTO_ACTOR_MODE = auto()
     SETU_GUIAUTO_ACTOR_URL = auto()
 
-    AUTOMATOR_NAME = auto()
-
     BROWSER_NAME = auto()
+    BROWSER_HEADLESS = auto()
     BROWSER_VERSION = auto()
     BROWSER_MAXIMIZE = auto()
     BROWSER_DIM_HEIGHT = auto()
@@ -77,7 +75,8 @@ class ArjunaOption(Enum):
     BROWSER_BIN_PATH = auto()
     BROWSER_PROXY_ON = auto()
 
-    GUIAUTO_INPUT_DIR = auto()
+    GUIAUTO_NAME = auto()
+    GUIAUTO_DIR = auto()
     GUIAUTO_NAMESPACE_DIR = auto()
     GUIAUTO_DEF_MULTICONTEXT = auto()
     GUIAUTO_CONTEXT = auto()
@@ -88,6 +87,7 @@ class ArjunaOption(Enum):
     GUIAUTO_MAX_WAIT = auto()
     GUIAUTO_SLOMO_ON = auto()
     GUIAUTO_SLOMO_INTERVAL = auto()
+    GUIAUTO_WITHX_YAML = auto()
 
     MOBILE_OS_NAME = auto()
     MOBILE_OS_VERSION = auto()
@@ -98,12 +98,13 @@ class ArjunaOption(Enum):
     SELENIUM_DRIVER_PROP = auto()
     SELENIUM_DRIVERS_DIR = auto()
     SELENIUM_DRIVER_PATH = auto()
+    SELENIUM_DRIVER_DOWNLOAD = auto()
+    SELENIUM_SERVICE_URL = auto()
 
-    APPIUM_HUB_URL = auto()
+    APPIUM_SERVICE_URL = auto()
     APPIUM_AUTO_LAUNCH = auto()
 
-    IMAGE_COMPARISON_MIN_SCORE = auto()
-
+    IMG_COMP_MIN_SCORE = auto()
 
 class Key(Enum):
 	NULL = auto()
@@ -202,10 +203,6 @@ class MobileOsName(Enum):
 class BrowserName(Enum):
     CHROME = auto()
     FIREFOX = auto()
-    SAFARI = auto()
-    IE = auto()
-    OPERA = auto()
-    HTML = auto()
 
 class AppiumAndroidBrowserName(Enum):
     BROWSER = auto()
@@ -411,6 +408,12 @@ class DataRefContextType(Enum):
     ROW = auto()
     COLUMN = auto()
 
+class GuiTemplate(Enum):
+    ELEMENT = auto()
+    MULTI_ELEMENT = auto()
+    DROPDOWN = auto()
+    RADIO_GROUP = auto()
+
 import locale
 locales = [i.upper() for i in locale.locale_alias.keys()]
 Locale = Enum('Locale', dict(zip(locales, range(len(locales)))))
\ No newline at end of file
