@@ -95,12 +95,9 @@ class DataSource(metaclass=abc.ABCMeta):
         out = []
         while True:
             try:
-                record = self.next() #.record
+                record = self.next()
                 out.append(record)
             except DataSourceFinished as e:
-                # print(e)
-                # import traceback
-                # traceback.print_exc()
                 break
         return out
 
@@ -144,7 +141,7 @@ class DsvFileListDataSource(FileDataSource):
         self._load_file()
 
     def process(self, data_record):
-        return ListDataRecord(data_record)
+        return DataRecord(**dict(data_record))
 
     def _load_file(self):
         self.reader = FileLine2ArrayReader(self.path, self.__delimiter)
@@ -157,7 +154,7 @@ class DsvFileMapDataSource(FileDataSource):
         self._load_file()
 
     def process(self, data_record):
-        return MapDataRecord(data_record)
+        return DataRecord(**dict(data_record))
 
     def _load_file(self):
         self.reader = FileLine2MapReader(self.path, self.__delimiter)
@@ -172,7 +169,7 @@ class IniFileDataSource(FileDataSource):
             raise Exception("Unsupported file extension for Ini reading.")
 
     def process(self, data_record):
-        return MapDataRecord(data_record)
+        return DataRecord(**dict(data_record))
 
     def _load_file(self):
         self.reader = IniFile2MapReader(self.path)
@@ -211,9 +208,7 @@ class ExcelFileMapDataSource(FileDataSource):
         return data_record.should_exclude()
 
     def process(self, data_record):
-        return MapDataRecord(data_record)
-
-
+        return DataRecord(**dict(data_record))
 
 class DummyDataSource(DataSource):
     MR = DataRecord()
@@ -265,6 +260,9 @@ class DataArrayDataSource(DataSource):
     def should_exclude(self, data_record):
         return False
 
+    def reset(self):
+        self.__iter = iter(self.records)
+
 
 class DataFunctionDataSource(DataSource):
     def __init__(self, func, *vargs, **kwargs):
@@ -273,10 +271,13 @@ class DataFunctionDataSource(DataSource):
         self.vargs = vargs
         self.kwargs = kwargs
         try:
-            self.__iter = iter(self.func(*self.vargs, **self.kwargs))
+            self.reset()
         except:
             raise Exception("data_function should return an object that is an iterable.")
 
+    def reset(self):
+        self.__iter = iter(self.func(*self.vargs, **self.kwargs))
+
     def get_next(self):
         obj = next(self.__iter)
         if isinstance(obj, DataRecord):
@@ -303,10 +304,13 @@ class DataClassDataSource(DataSource):
         self.vargs = vargs
         self.kwargs = kwargs
         try:
-            self.__iter = iter(self.klass(*self.vargs, **self.kwargs))
+            self.reset()
         except:
             raise Exception("data_class should implement Python iteration protocol.")
 
+    def reset(self):
+        self.__iter = iter(self.klass(*self.vargs, **self.kwargs))
+
     def get_next(self):
         obj = next(self.__iter)
         if isinstance(obj, DataRecord):
@@ -340,6 +344,9 @@ class MultiDataSource(DataSource):
         except:
             raise StopIteration()
 
+    def reset(self):
+        self.def_iter = iter(self.dsdefs)
+
     def get_next(self):
         if self.current_dsource is None:
             self.__init_next_source()
