@@ -38,23 +38,23 @@ class ElementContainer(metaclass=abc.ABCMeta):
         return self.__element_finder
 
     @property
-    def max_wait_time(self):
+    def max_wait(self):
         return self.config.value("guiauto.max.wait")
 
-    def wait_until_element_absent(self, lmd, max_wait_time=None):
-        max_wait_time = max_wait_time and max_wait_time or self.max_wait_time
-        return self.__container_conditions.AbsenceOfElement(lmd).wait(max_wait_time=max_wait_time)
+    def __elem_wait(self, emd):
+        return emd.max_wait and emd.max_wait or self.max_wait
 
-    def wait_until_element_found(self, gui_element, max_wait_time=None):
-        max_wait_time = max_wait_time and max_wait_time or self.max_wait_time
-        return self.__container_conditions.PresenceOfElement(gui_element).wait(max_wait_time=max_wait_time)
+    def wait_until_element_absent(self, emd):
+        return self.__container_conditions.AbsenceOfElement(emd).wait(max_wait=self.__elem_wait(emd))
 
-    def wait_until_multielement_found(self, multi_guielement, max_wait_time=None):
-        max_wait_time = max_wait_time and max_wait_time or self.max_wait_time
-        return self.__container_conditions.PresenceOfMultiElement(multi_guielement).wait(max_wait_time=max_wait_time)
+    def wait_until_element_found(self, gui_element):
+        return self.__container_conditions.PresenceOfElement(gui_element).wait(max_wait=self.__elem_wait(gui_element.emd))
 
-    def load_multielement(self, multi_guielement, max_wait_time=None):
-        locator_type, locator_value, size, dispatcher = self.wait_until_multielement_found(multi_guielement, max_wait_time=max_wait_time)
+    def wait_until_multielement_found(self, multi_guielement):
+        return self.__container_conditions.PresenceOfMultiElement(multi_guielement).wait(max_wait=self.__elem_wait(multi_guielement.emd))
+
+    def load_multielement(self, multi_guielement):
+        locator_type, locator_value, size, dispatcher = self.wait_until_multielement_found(multi_guielement)
         if size == 0:
             raise Exception("MultiElement could not be found with any of the provided locators.")
         multi_guielement.located_with = locator_type, locator_value
@@ -62,8 +62,8 @@ class ElementContainer(metaclass=abc.ABCMeta):
         multi_guielement.size = size
         multi_guielement.load_source_parser()
 
-    def load_element(self, gui_element, max_wait_time=None):
-        locator_type, locator_value, size, dispatcher = self.wait_until_element_found(gui_element, max_wait_time=max_wait_time)
+    def load_element(self, gui_element):
+        locator_type, locator_value, size, dispatcher = self.wait_until_element_found(gui_element)
         gui_element.located_with = locator_type, locator_value
         gui_element.dispatcher = dispatcher
         gui_element.load_source_parser()
\ No newline at end of file
