@@ -61,52 +61,9 @@ class GuiDef:
     def is_empty(self):
         return seff.__ns.is_empty()
 
-    # def add_child(self, label, automator, file_def_path):
-    #     self.__children.append(
-    #         Gui(self.__name_store, self.__namespace_dir, label, self.__automator, file_def_path)
-    # )
-
     def get_emd(self, label):
         return self.__ns.get_meta_data(label, self.__auto_context)
 
-    def convert_to_lmd(self, *locators):
-        final_locators = []
-        for raw_locator in locators:
-            if raw_locator.wtype.upper().strip() == "LABEL":
-                emd = self.get_emd(raw_locator.wvalue)
-                for loc in emd.raw_locators:
-                    if not raw_locator.named_args:
-                        final_locators.append(Locator(ltype=loc.ltype, lvalue=loc.lvalue), named_args={})
-                    else:
-                        final_locators.append(Locator(ltype=loc.ltype, lvalue=loc.lvalue), named_args=raw_locator.named_args)
-            else:
-                if not raw_locator.named_args:
-                    final_locators.append(Locator(ltype=raw_locator.wtype, lvalue=raw_locator.wvalue), named_args={})
-                else:
-                    final_locators.append(Locator(ltype=raw_locator.ltype, lvalue=raw_locator.lvalue), named_args=raw_locator.named_args)
-        return GuiElementMetaData(final_locators)
-
-    def __gns_locators_as_with_locators(self, label):
-        emd = self.__ns.get_meta_data(label, self.__auto_context)
-        out = []
-        for loc in emd.raw_locators:
-            underscore = loc.ltype.lower().endswith("attr") and "_" or ""
-            wobj = getattr(With, underscore + loc.ltype.lower()) (loc.lvalue)# e.g. getattr(With, "_" + "ID".lower())("abc")
-            out.append(wobj)
-        return out
-
-    def convert_to_with(self, locator):
-        from arjuna.interact.gui.auto.finder._with import With
-        out_list = []
-        impl_with = locator.as_impl_locator()
-        for wobj in self.__gns_locators_as_with_locators(impl_with.wvalue):
-            # underscore = loc.ltype.lower().endswith("attr") and "_" or ""
-            # wobj = getattr(With, underscore + loc.ltype.lower()) (loc.lvalue)# e.g. getattr(With, "_" + "ID".lower())("abc")
-            if locator.named_args:
-                wobj.format(**locator.named_args)
-            out_list.append(wobj)
-        return out_list
-
     @property
     def root_element_name(self):
         try:
@@ -123,10 +80,6 @@ class GuiDef:
             # Defining __load__ is optional for GNS files.
             return None
 
-    def create_dispatcher(self):
-        # Pages don't use any dispatcher
-        pass
-
 class GuiFactory:
 
     @classmethod
@@ -140,7 +93,7 @@ class GuiFactory:
             if not os.path.isdir(considered_path):
                 raise Exception("Provided root definition path is not a directory: {}".format(app_def_dir))
 
-        app = GuiDef(automator, os.path.join(considered_path, "HomePage.yaml"), label=name)
+        app = GuiDef(automator, os.path.join(considered_path, "HomeGuiPage.yaml"), label=name)
         children_dir = os.path.join(considered_path, "children")
         if os.path.isdir(children_dir):
             lfiles = os.listdir(children_dir)
@@ -152,4 +105,44 @@ class GuiFactory:
 
     @classmethod
     def create_guidef(cls, automator, def_path):
-        return GuiDef(automator, def_path)
\ No newline at end of file
+        return GuiDef(automator, def_path)
+
+
+# Temp back from GuiDef of older implementation
+
+# def __gns_locators_as_with_locators(self, label):
+#     emd = self.__ns.get_meta_data(label, self.__auto_context)
+#     out = []
+#     for loc in emd.raw_locators:
+#         underscore = loc.ltype.lower().endswith("attr") and "_" or ""
+#         wobj = getattr(With, underscore + loc.ltype.lower()) (loc.lvalue)# e.g. getattr(With, "_" + "ID".lower())("abc")
+#         out.append(wobj)
+#     return out
+
+# def convert_to_with(self, locator):
+#     from arjuna.interact.gui.auto.finder._with import With
+#     out_list = []
+#     impl_with = locator.as_impl_locator()
+#     for wobj in self.__gns_locators_as_with_locators(impl_with.wvalue):
+#         # underscore = loc.ltype.lower().endswith("attr") and "_" or ""
+#         # wobj = getattr(With, underscore + loc.ltype.lower()) (loc.lvalue)# e.g. getattr(With, "_" + "ID".lower())("abc")
+#         if locator.named_args:
+#             wobj.format(**locator.named_args)
+#         out_list.append(wobj)
+#     return out_list
+# def convert_to_emd(self, *locators):
+#     final_locators = []
+#     for raw_locator in locators:
+#         if raw_locator.wtype.upper().strip() == "LABEL":
+#             emd = self.get_emd(raw_locator.wvalue)
+#             for loc in emd.raw_locators:
+#                 if not raw_locator.named_args:
+#                     final_locators.append(Locator(ltype=loc.ltype, lvalue=loc.lvalue), named_args={})
+#                 else:
+#                     final_locators.append(Locator(ltype=loc.ltype, lvalue=loc.lvalue), named_args=raw_locator.named_args)
+#         else:
+#             if not raw_locator.named_args:
+#                 final_locators.append(Locator(ltype=raw_locator.wtype, lvalue=raw_locator.wvalue), named_args={})
+#             else:
+#                 final_locators.append(Locator(ltype=raw_locator.ltype, lvalue=raw_locator.lvalue), named_args=raw_locator.named_args)
+#     return GuiElementMetaData(final_locators)
\ No newline at end of file
