@@ -82,7 +82,7 @@ class GuiNamespace:
         return not self.__ns
 
     def add_element_meta_data(self, name, context, raw_locators, meta):
-        emd = GuiElementMetaData.create_lmd(*raw_locators, meta=meta)
+        emd = GuiElementMetaData.create_emd(*raw_locators, meta=meta)
         name = name.lower()
         if not self.has(name):
             self.__ns[name] = {}
@@ -217,7 +217,7 @@ class YamlGnsLoader(BaseGuiNamespaceLoader):
                         iloc = ImplWith(wtype=wtype, wvalue=wvalue, has_content_locator=False)
                         self.__ns[label.lower()]["locators"][self.__context].append(iloc)
                     else:
-                        self.__ns[label.lower()]["meta"][wtype] = wvalue
+                        self.__ns[label.lower()]["meta"][wtype.lower()] = wvalue
                 else:
                     if self.__withx.has_locator(loc):
                         wx = self.__withx
