@@ -39,12 +39,19 @@ def new_project_dir(input):
     proj_name = os.path.basename(input)
     lname_check("Project", proj_name)
     if os.path.exists(input):
-        print('Project path already exist: {}'.format(input))
+        print('Project path already exists: {}'.format(input))
         return input
     else:
         os.makedirs(input)
         return input
 
+def absolute_file_path(input):
+    if not os.path.isabs(input) or not os.path.isfile(input):
+        print('Config file path does not exist or is not a file: {}'.format(input))
+        print('Exiting...', file=sys.stderr)
+        sys.exit(1)
+    return input
+
 def project_dir(input):
     if not os.path.exists(input):
         print('Project path does not exist: {}'.format(input))
@@ -61,7 +68,7 @@ def project_dir(input):
 
 def lname_check(context, input):
     if not re.match(VNREGEX, input):
-        print('Invalid {} name provided.'.format(context), file=sys.stderr)
+        print('Invalid {} name {} provided.'.format(context, input), file=sys.stderr)
         print(VNREGEX_TEXT.format(context), file=sys.stderr)
         print('Exiting...', file=sys.stderr)
         sys.exit(1)
